==> haskell-clientsession-0.9.2.0-25-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clientsession
version:              0.9.2.0
visibility:           public
id:                   clientsession-0.9.2.0-FWXB8JXiMEYLEneDZrrOV0
key:                  clientsession-0.9.2.0-FWXB8JXiMEYLEneDZrrOV0
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>

stability:            stable
homepage:             http://github.com/yesodweb/clientsession/tree/master
synopsis:             Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.

category:             Web
abi:                  6352ed1f735f69cc6d21da77ca3321ea
exposed:              True
exposed-modules:      Web.ClientSession
hidden-modules:       System.LookupEnv
import-dirs:          /usr/lib/ghc-9.2.8/site-local/clientsession-0.9.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/clientsession-0.9.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-clientsession
hs-libraries:         HSclientsession-0.9.2.0-FWXB8JXiMEYLEneDZrrOV0
depends:
    base-4.16.4.0 base64-bytestring-1.2.1.0-FdWgvlJbicB4WMe5vVN4jG
    bytestring-0.11.4.0 cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    crypto-api-0.13.3-95IFBy4WvL6L3p6UFm5MLc
    cryptonite-0.30-B8lqKo2bgZjIAiaKsp19j7 directory-1.3.6.2
    entropy-0.4.1.10-C5y4ZMubclPFkOssafbGqV
    setenv-0.1.1.3-3TgCzb5FKNIC6AFHCaPUY
    skein-1.0.9.4-I3T91p6XZaISUb14OUQBP
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg

haddock-interfaces:
    /usr/share/doc/haskell-clientsession/html/clientsession.haddock

haddock-html:         /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clientsession-0.9.2.0-27-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-clientsession.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clientsession
version:              0.9.2.0
visibility:           public
id:                   clientsession-0.9.2.0-AAJljp6JRWyFFpWYTcy5fi
key:                  clientsession-0.9.2.0-AAJljp6JRWyFFpWYTcy5fi
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>

stability:            stable
homepage:             http://github.com/yesodweb/clientsession/tree/master
synopsis:             Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.

category:             Web
abi:                  a631741ac7aaf5d9d0aaf5cc93c269f8
exposed:              True
exposed-modules:      Web.ClientSession
hidden-modules:       System.LookupEnv
import-dirs:          /usr/lib/ghc-9.2.8/site-local/clientsession-0.9.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/clientsession-0.9.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-clientsession
hs-libraries:         HSclientsession-0.9.2.0-AAJljp6JRWyFFpWYTcy5fi
depends:
    base-4.16.4.0 base64-bytestring-1.2.1.0-DECs32jOMrhU6x3ypSYAj
    bytestring-0.11.4.0 cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    crypto-api-0.13.3-95IFBy4WvL6L3p6UFm5MLc
    cryptonite-0.30-7YCFiEak3iS4jVbhqnIKep directory-1.3.6.2
    entropy-0.4.1.10-C5y4ZMubclPFkOssafbGqV
    setenv-0.1.1.3-3TgCzb5FKNIC6AFHCaPUY
    skein-1.0.9.4-I3T91p6XZaISUb14OUQBP
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg

haddock-interfaces:
    /usr/share/doc/haskell-clientsession/html/clientsession.haddock

haddock-html:         /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
